summaryrefslogtreecommitdiffstats
path: root/ui/aura/root_window.h
diff options
context:
space:
mode:
authorben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-11-20 01:41:51 +0000
committerben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-11-20 01:41:51 +0000
commit8520ebd2d0fad750b0841f4d8dae1e517f0c400f (patch)
tree0d95131d2dd9ee39aa931034484e0a89797d591b /ui/aura/root_window.h
parentf0c4809951a377e88d6b0c19a97cd50dab5d1f10 (diff)
downloadchromium_src-8520ebd2d0fad750b0841f4d8dae1e517f0c400f.zip
chromium_src-8520ebd2d0fad750b0841f4d8dae1e517f0c400f.tar.gz
chromium_src-8520ebd2d0fad750b0841f4d8dae1e517f0c400f.tar.bz2
Revert 236048 "Rename RootWindowHost* to WindowTreeHost*"
> Rename RootWindowHost* to WindowTreeHost* > > TBR=sky@chromium.org > http://crbug.com/308843 > > Review URL: https://codereview.chromium.org/76583003 TBR=ben@chromium.org Review URL: https://codereview.chromium.org/77203002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@236093 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ui/aura/root_window.h')
-rw-r--r--ui/aura/root_window.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/ui/aura/root_window.h b/ui/aura/root_window.h
index f9a17af..7f8d0b1 100644
--- a/ui/aura/root_window.h
+++ b/ui/aura/root_window.h
@@ -45,7 +45,7 @@ class ViewProp;
namespace aura {
class RootWindow;
-class WindowTreeHost;
+class RootWindowHost;
class RootWindowObserver;
class TestScreen;
@@ -54,7 +54,7 @@ class AURA_EXPORT RootWindow : public ui::EventDispatcherDelegate,
public ui::GestureEventHelper,
public ui::LayerAnimationObserver,
public aura::client::CaptureDelegate,
- public aura::WindowTreeHostDelegate {
+ public aura::RootWindowHostDelegate {
public:
struct AURA_EXPORT CreateParams {
// CreateParams with initial_bounds and default host in pixel.
@@ -65,13 +65,13 @@ class AURA_EXPORT RootWindow : public ui::EventDispatcherDelegate,
// A host to use in place of the default one that RootWindow will create.
// NULL by default.
- WindowTreeHost* host;
+ RootWindowHost* host;
};
explicit RootWindow(const CreateParams& params);
virtual ~RootWindow();
// Returns the WindowTreeHost for the specified accelerated widget, or NULL
// if there is none associated.
static RootWindow* GetForAcceleratedWidget(gfx::AcceleratedWidget widget);
@@ -79,11 +79,11 @@ class AURA_EXPORT RootWindow : public ui::EventDispatcherDelegate,
return const_cast<Window*>(const_cast<const RootWindow*>(this)->window());
}
const Window* window() const { return window_.get(); }
- WindowTreeHost* host() {
- return const_cast<WindowTreeHost*>(
+ RootWindowHost* host() {
+ return const_cast<RootWindowHost*>(
const_cast<const RootWindow*>(this)->host());
}
- const WindowTreeHost* host() const { return host_.get(); }
+ const RootWindowHost* host() const { return host_.get(); }
gfx::NativeCursor last_cursor() const { return last_cursor_; }
Window* mouse_pressed_handler() { return mouse_pressed_handler_; }
Window* mouse_moved_handler() { return mouse_moved_handler_; }
@@ -99,7 +99,7 @@ class AURA_EXPORT RootWindow : public ui::EventDispatcherDelegate,
// types (although the latter is currently a no-op).
void RepostEvent(const ui::LocatedEvent& event);
- WindowTreeHostDelegate* AsWindowTreeHostDelegate();
+ RootWindowHostDelegate* AsRootWindowHostDelegate();
// Gets/sets the size of the host window.
void SetHostSize(const gfx::Size& size_in_pixel);
@@ -130,7 +130,7 @@ class AURA_EXPORT RootWindow : public ui::EventDispatcherDelegate,
// Handles a gesture event. Returns true if handled. Unlike the other
// event-dispatching function (e.g. for touch/mouse/keyboard events), gesture
// events are dispatched from GestureRecognizer instead of WindowTreeHost.
void DispatchGestureEvent(ui::GestureEvent* event);
// Invoked when |window| is being destroyed.
@@ -159,7 +159,7 @@ class AURA_EXPORT RootWindow : public ui::EventDispatcherDelegate,
void OnKeyboardMappingChanged();
// The system windowing system has sent a request that we close our window.
- void OnWindowTreeHostCloseRequested();
+ void OnRootWindowHostCloseRequested();
// Add/remove observer. There is no need to remove the observer if
// the root window is being deleted. In particular, you SHOULD NOT remove
@@ -208,7 +208,7 @@ class AURA_EXPORT RootWindow : public ui::EventDispatcherDelegate,
};
// Updates the event with the appropriate transform for the device scale
// factor. The WindowTreeHostDelegate dispatches events in the physical pixel
// coordinate. But the event processing from RootWindow onwards happen in
// device-independent pixel coordinate. So it is necessary to update the event
// received from the host.
@@ -264,7 +264,7 @@ class AURA_EXPORT RootWindow : public ui::EventDispatcherDelegate,
virtual void OnLayerAnimationAborted(
ui::LayerAnimationSequence* animation) OVERRIDE;
// Overridden from aura::WindowTreeHostDelegate:
virtual bool OnHostKeyEvent(ui::KeyEvent* event) OVERRIDE;
virtual bool OnHostMouseEvent(ui::MouseEvent* event) OVERRIDE;
virtual bool OnHostScrollEvent(ui::ScrollEvent* event) OVERRIDE;
@@ -286,7 +286,7 @@ class AURA_EXPORT RootWindow : public ui::EventDispatcherDelegate,
// dispatch held and newly incoming mouse and touch events, typically when an
// event other than one of these needs dispatching or a matching
// ReleaseMouseMoves()/ReleaseTouchMoves() is called. NOTE: because these
// methods dispatch events from WindowTreeHost the coordinates are in terms of
// the root.
ui::EventDispatchDetails DispatchMouseEventImpl(ui::MouseEvent* event)
WARN_UNUSED_RESULT;
@@ -312,7 +312,7 @@ class AURA_EXPORT RootWindow : public ui::EventDispatcherDelegate,
// TODO(beng): evaluate the ideal ownership model.
scoped_ptr<Window> window_;
- scoped_ptr<WindowTreeHost> host_;
+ scoped_ptr<RootWindowHost> host_;
// Touch ids that are currently down.
uint32 touch_ids_down_;
@@ -65,13 +65,13 @@ class AURA_EXPORT RootWindow : public ui::EventDispatcherDelegate,
explicit RootWindow(const CreateParams& params);
virtual ~RootWindow();
- // Returns the WindowTreeHost for the specified accelerated widget, or NULL
+ // Returns the RootWindowHost for the specified accelerated widget, or NULL
// if there is none associated.
static RootWindow* GetForAcceleratedWidget(gfx::AcceleratedWidget widget);
@@ -130,7 +130,7 @@ class AURA_EXPORT RootWindow : public ui::EventDispatcherDelegate,
// Handles a gesture event. Returns true if handled. Unlike the other
// event-dispatching function (e.g. for touch/mouse/keyboard events), gesture
- // events are dispatched from GestureRecognizer instead of WindowTreeHost.
+ // events are dispatched from GestureRecognizer instead of RootWindowHost.
void DispatchGestureEvent(ui::GestureEvent* event);
// Invoked when |window| is being destroyed.
@@ -208,7 +208,7 @@ class AURA_EXPORT RootWindow : public ui::EventDispatcherDelegate,
};
// Updates the event with the appropriate transform for the device scale
- // factor. The WindowTreeHostDelegate dispatches events in the physical pixel
+ // factor. The RootWindowHostDelegate dispatches events in the physical pixel
// coordinate. But the event processing from RootWindow onwards happen in
// device-independent pixel coordinate. So it is necessary to update the event
@@ -264,7 +264,7 @@ class AURA_EXPORT RootWindow : public ui::EventDispatcherDelegate,
virtual void OnLayerAnimationAborted(
ui::LayerAnimationSequence* animation) OVERRIDE;
- // Overridden from aura::WindowTreeHostDelegate:
+ // Overridden from aura::RootWindowHostDelegate:
virtual bool OnHostKeyEvent(ui::KeyEvent* event) OVERRIDE;
virtual bool OnHostMouseEvent(ui::MouseEvent* event) OVERRIDE;
@@ -286,7 +286,7 @@ class AURA_EXPORT RootWindow : public ui::EventDispatcherDelegate,
// event other than one of these needs dispatching or a matching
// ReleaseMouseMoves()/ReleaseTouchMoves() is called. NOTE: because these
- // methods dispatch events from WindowTreeHost the coordinates are in terms of
+ // methods dispatch events from RootWindowHost the coordinates are in terms of
// the root.
ui::EventDispatchDetails DispatchMouseEventImpl(ui::MouseEvent* event)